==> jc-1.4.0.tar.gz: gnu/xml/xpath/DocumentOrderComparator.h <==
// public class gnu.xml.xpath.DocumentOrderComparator

// class file dependencies
// @dep_class 5a73d1e4b532a2a5 gnu_xml_xpath_DocumentOrderComparator
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_xpath_DocumentOrderComparator_H_
#define _JC_gnu_xml_xpath_DocumentOrderComparator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_DocumentOrderComparator$sub_refs	_jc_gnu_xml_xpath_DocumentOrderComparator$sub_refs;
typedef struct _jc_gnu_xml_xpath_DocumentOrderComparator$sub_nonrefs	_jc_gnu_xml_xpath_DocumentOrderComparator$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_DocumentOrderComparator$refs	_jc_gnu_xml_xpath_DocumentOrderComparator$refs;
typedef struct _jc_gnu_xml_xpath_DocumentOrderComparator$nonrefs	_jc_gnu_xml_xpath_DocumentOrderComparator$nonrefs;
typedef struct _jc_gnu_xml_xpath_DocumentOrderComparator$object	_jc_gnu_xml_xpath_DocumentOrderComparator$object;

typedef const struct _jc_gnu_xml_xpath_DocumentOrderComparator$vmethods	_jc_gnu_xml_xpath_DocumentOrderComparator$vmethods;
typedef const struct _jc_gnu_xml_xpath_DocumentOrderComparator$vtable	_jc_gnu_xml_xpath_DocumentOrderComparator$vtable;
typedef const struct _jc_gnu_xml_xpath_DocumentOrderComparator$vtype	_jc_gnu_xml_xpath_DocumentOrderComparator$vtype;

// Constructors
extern void _jc_gnu_xml_xpath_DocumentOrderComparator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_DocumentOrderComparator$object *);

// Virtual methods
extern jint _jc_gnu_xml_xpath_DocumentOrderComparator$method$compare$ef65339aa5f9531b(_jc_env *, struct _jc_gnu_xml_xpath_DocumentOrderComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_xpath_DocumentOrderComparator$method_info$compare$ef65339aa5f9531b;

// Virtual methods structure
struct _jc_gnu_xml_xpath_DocumentOrderComparator$vmethods {
	jint	(*compare$ef65339aa5f9531b)(_jc_env *, struct _jc_gnu_xml_xpath_DocumentOrderComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_gnu_xml_xpath_DocumentOrderComparator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_DocumentOrderComparator$vmethods	gnu_xml_xpath_DocumentOrderComparator;
};

// Vtype
struct _jc_gnu_xml_xpath_DocumentOrderComparator$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_DocumentOrderComparator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_DocumentOrderComparator$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_DocumentOrderComparator$refs {
    _jc_gnu_xml_xpath_DocumentOrderComparator$sub_refs	gnu_xml_xpath_DocumentOrderComparator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_DocumentOrderComparator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_DocumentOrderComparator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_DocumentOrderComparator$sub_nonrefs	gnu_xml_xpath_DocumentOrderComparator;
};

// Object instance structure
struct _jc_gnu_xml_xpath_DocumentOrderComparator$object {
	_jc_gnu_xml_xpath_DocumentOrderComparator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_DocumentOrderComparator$vtype	*vtype;
	_jc_gnu_xml_xpath_DocumentOrderComparator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_DocumentOrderComparator$vtype _jc_gnu_xml_xpath_DocumentOrderComparator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_DocumentOrderComparator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_DocumentOrderComparator$class_object;

#endif	/* _JC_gnu_xml_xpath_DocumentOrderComparator_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/xpath/DocumentOrderComparator.h <==
// public class gnu.xml.xpath.DocumentOrderComparator

// class file dependencies
// @dep_class 5a73d1e4b532a2a5 gnu_xml_xpath_DocumentOrderComparator
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_xpath_DocumentOrderComparator_H_
#define _JC_gnu_xml_xpath_DocumentOrderComparator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_DocumentOrderComparator$sub_refs	_jc_gnu_xml_xpath_DocumentOrderComparator$sub_refs;
typedef struct _jc_gnu_xml_xpath_DocumentOrderComparator$sub_nonrefs	_jc_gnu_xml_xpath_DocumentOrderComparator$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_DocumentOrderComparator$refs	_jc_gnu_xml_xpath_DocumentOrderComparator$refs;
typedef struct _jc_gnu_xml_xpath_DocumentOrderComparator$nonrefs	_jc_gnu_xml_xpath_DocumentOrderComparator$nonrefs;
typedef struct _jc_gnu_xml_xpath_DocumentOrderComparator$object	_jc_gnu_xml_xpath_DocumentOrderComparator$object;

typedef const struct _jc_gnu_xml_xpath_DocumentOrderComparator$vmethods	_jc_gnu_xml_xpath_DocumentOrderComparator$vmethods;
typedef const struct _jc_gnu_xml_xpath_DocumentOrderComparator$vtable	_jc_gnu_xml_xpath_DocumentOrderComparator$vtable;
typedef const struct _jc_gnu_xml_xpath_DocumentOrderComparator$vtype	_jc_gnu_xml_xpath_DocumentOrderComparator$vtype;

// Constructors
extern void _jc_gnu_xml_xpath_DocumentOrderComparator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_DocumentOrderComparator$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_gnu_xml_xpath_DocumentOrderComparator$method$compare$ef65339aa5f9531b(_jc_env *, struct _jc_gnu_xml_xpath_DocumentOrderComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_xpath_DocumentOrderComparator$method_info$compare$ef65339aa5f9531b;

// Virtual methods structure
struct _jc_gnu_xml_xpath_DocumentOrderComparator$vmethods {
	jint	(*compare$ef65339aa5f9531b)(_jc_env *, struct _jc_gnu_xml_xpath_DocumentOrderComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_xpath_DocumentOrderComparator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_DocumentOrderComparator$vmethods	gnu_xml_xpath_DocumentOrderComparator;
};

// Vtype
struct _jc_gnu_xml_xpath_DocumentOrderComparator$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_DocumentOrderComparator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_DocumentOrderComparator$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_DocumentOrderComparator$refs {
    _jc_gnu_xml_xpath_DocumentOrderComparator$sub_refs	gnu_xml_xpath_DocumentOrderComparator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_DocumentOrderComparator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_DocumentOrderComparator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_DocumentOrderComparator$sub_nonrefs	gnu_xml_xpath_DocumentOrderComparator;
};

// Object instance structure
struct _jc_gnu_xml_xpath_DocumentOrderComparator$object {
	_jc_gnu_xml_xpath_DocumentOrderComparator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_DocumentOrderComparator$vtype	*vtype;
	_jc_gnu_xml_xpath_DocumentOrderComparator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_DocumentOrderComparator$vtype _jc_gnu_xml_xpath_DocumentOrderComparator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_DocumentOrderComparator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_DocumentOrderComparator$class_object;

#endif	/* _JC_gnu_xml_xpath_DocumentOrderComparator_H_ */
